# DjangoLDP Community

## Create & assign your users to a default community

To automatically create a community and assign all your local users to it, use the following command:

```bash
./manage.py create_community --name="My community"
```
